import styled, { css } from "styled-components";
import { HTMLAttributes } from "react";
import Loader from "@src/components/Common/Loader/Loader";

export type LoadingButtonProps = HTMLAttributes<HTMLButtonElement> & {
  isLoading?: boolean;
};

export const LoadingButton = ({
  isLoading = false,

  children,
  ...attributes
}: LoadingButtonProps) => {
  return (
    <Container id="common-async-button" {...attributes} isLoading={isLoading}>
      {children}
      {isLoading && <Loader className="common-async-button__loader" />}
    </Container>
  );
};

const loadingStyles = css`
  pointer-events: none;

  &::before {
    content: "";
    width: 100%;
    height: 100%;
    position: absolute;
    top: 0;
    left: 0;
    background-color: rgba(255, 255, 255, 0.5);
    cursor: not-allowed;
  }
`;

const Container = styled.button<{ isLoading: boolean }>`
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 16px;
  position: relative;
  cursor: pointer;

  ${({ isLoading }) => isLoading && loadingStyles}
`;
