import React, { useState } from "react";
import Checkbox, { CheckboxProps } from "./index";
import { Meta, StoryObj } from "@storybook/react";

const meta = {
  title: "component/Checkbox",
  component: Checkbox,
  parameters: {
    layout: "centered",
  },
  argTypes: {
    checked: { control: "boolean" },
    disabled: { control: "boolean" },
    activeColor: {
      control: "color",
      description:
        "지정한 색상으로 체크박스의 border color와 check 아이콘의 stroke color 스타일이 변경됩니다.",
    },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof Checkbox>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: CheckboxProps) => {
  const [isChecked, setIsChecked] = useState<string>("");

  const handleOnChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    setIsChecked(e.currentTarget.id);

    if (e.currentTarget.id === isChecked) setIsChecked("");
  };

  return (
    <Checkbox
      {...args}
      id="label"
      checked={"label" === isChecked}
      onChange={handleOnChange}
    />
  );
};

Default.args = {
  checked: false,
  children: "label",
};

export const Disabled: Story = (args: CheckboxProps) => {
  return <Checkbox {...args} />;
};

Disabled.args = {
  checked: true,
  children: "label",
  disabled: true,
};
