import styled from "styled-components";
import { useMemo } from "react";
import { colors } from "@core/colors/colors";
import { CheckIcon } from "@assets/Icon";

type CheckboxStatus = "CHECKED" | "DEFAULT" | "DISABLED";

export type CheckboxProps = {
  id?: string;
  children?: string;
  checked: boolean;
  onChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
  disabled?: boolean;
  activeColor?: string;
};

const Checkbox = ({
  id = "",
  children,
  checked,
  onChange,
  disabled = false,
  activeColor,
}: CheckboxProps) => {
  const status: CheckboxStatus = useMemo(() => {
    if (disabled) return "DISABLED";
    if (checked) return "CHECKED";
    return "DEFAULT";
  }, [checked]);

  const styles: {
    [key in CheckboxStatus]: {
      [style in "color"]: string;
    };
  } = {
    CHECKED: {
      color: activeColor || colors.primary[500],
    },
    DEFAULT: {
      color: colors.gray[300],
    },
    DISABLED: {
      color: colors.gray[400],
    },
  };

  return (
    <Conainer className="common-checkbox">
      <CheckboxContainer className="common-checkbox__checkbox">
        <input
          type="checkbox"
          id={id}
          checked={checked}
          onChange={(e) => onChange(e)}
          disabled={disabled}
          style={{
            borderColor: styles[status].color,
          }}
        />
        {checked && <CheckIcon size={12} stroke={styles[status].color} />}
      </CheckboxContainer>
      {children}
    </Conainer>
  );
};

export default Checkbox;

const Conainer = styled.label`
  display: flex;
  align-items: center;
  gap: 8px;

  &:disabled {
    color: ${colors.gray[400]};
  }
`;

const CheckboxContainer = styled.div`
  width: 16px;
  height: 16px;

  position: relative;

  & > input {
    width: 100%;
    height: 100%;
    appearance: none;
    border: 1px solid ${colors.gray[200]};
    border-radius: 4px;

    cursor: pointer;

    &:disabled {
      background-color: ${colors.gray[100]};
      border-color: ${colors.gray[300]};
    }
  }

  & > svg {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);

    cursor: pointer;
  }
`;
