import styled, { CSSProperties } from "styled-components";

type Size = "small" | "large";

type Props = {
  className?: string;
  size?: Size;
  style?: CSSProperties;
};

const Loader = ({ className, size = "small", style }: Props) => {
  const styles: { [key in Size]: CSSProperties } = {
    small: {
      width: 16,
      height: 16,
      borderWidth: 2,
    },
    large: {
      width: 48,
      height: 48,
      fontSize: 6,
    },
  };

  return (
    <Container className={className} style={{ ...styles[size], ...style }} />
  );
};

export default Loader;

const Container = styled.span`
  display: inline-block;
  border: 1px solid #fff;
  border-bottom-color: transparent;
  border-radius: 50%;
  animation: rotation 1s linear infinite;

  @keyframes rotation {
    0% {
      transform: rotate(0deg);
    }
    100% {
      transform: rotate(360deg);
    }
  }
`;
