import React from "react";
import { options, OptionTypes } from "../DropdownOptionData";
import { Meta, StoryObj } from "@storybook/react";
import MultipleDropdown, { MultipleDropdownProps } from "./index";
import { useState } from "react";

const meta = {
  title: "component/Dropdown/MultipleDropdown",
  component: MultipleDropdown,
  decorators: [
    (Story) => (
      <div
        style={{
          width: "850px",
          display: "flex",
          justifyContent: "center",
          overflow: "visible",
        }}
      >
        <Story />
      </div>
    ),
  ],
  parameters: {
    layout: "centered",
    docs: {
      story: {
        height: "500px",
      },
    },
  },
  argTypes: {
    disable: { control: "boolean" },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof MultipleDropdown>;

export default meta;

type Story = StoryObj<typeof meta>;

export const Default: Story = (args: MultipleDropdownProps<OptionTypes>) => {
  const [value, setValue] = useState<OptionTypes[]>([]);

  return (
    <MultipleDropdown
      {...args}
      value={value}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onClick={(option) => setValue(option)}
    />
  );
};

Default.args = {
  value: [],
  options: options,
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

export const JSX_Element: Story = (
  args: MultipleDropdownProps<OptionTypes>
) => {
  const [value, setValue] = useState<OptionTypes[]>([]);

  return (
    <MultipleDropdown
      {...args}
      value={value}
      optionKey={(value) => value.phonePlanId}
      optionLabel={(value) => value.name}
      onClick={(option) => setValue(option)}
      optionElement={({ option }) => (
        <>
          <p>{option.name}</p>
          <span>{option.price.toLocaleString()}원</span>
        </>
      )}
    />
  );
};

JSX_Element.args = {
  value: [],
  options: options,
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};

export const Empty_Data: Story = (args: MultipleDropdownProps<OptionTypes>) => {
  return <MultipleDropdown {...args} />;
};

Empty_Data.args = {
  value: [],
  options: [],
  optionKey: () => "",
  optionLabel: () => "",
  placeholder: "multi",
};
