import { useEffect, useState } from "react";
import { SliderProps } from "../Slider";
import { SliderContainer, SliderStyle } from "../Slider/Slider.styled";
import { DistanceSliderContainer } from "./DistanceSlider.styled";

export type DiatanceSliderValueKey = "minValue" | "maxValue";

export type DistanceSliderProps = Omit<SliderProps, "value" | "onChange"> & {
  value: {
    [key in DiatanceSliderValueKey]: number;
  };
  onChange: (name: DiatanceSliderValueKey, value: number) => void;
};

const DistanceSlider = ({ value, onChange, min, max }: DistanceSliderProps) => {
  const DistanceValueKeyArray: DiatanceSliderValueKey[] = [
    "minValue",
    "maxValue",
  ];
  const [isActive, setIsActive] = useState<DiatanceSliderValueKey>();
  const [activeSize, setActiveSize] = useState<{
    minActiveSize: number;
    maxActiveSize: number;
  }>({ minActiveSize: 0, maxActiveSize: 0 });

  const valueToUse = (key: DiatanceSliderValueKey) => {
    if (key === "minValue") {
      return value.minValue < min ? min : value.minValue;
    } else if (key === "maxValue") {
      return value.maxValue > max ? max : value.maxValue;
    }
    return 0;
  };

  const activeStyle = (activeSize: number) => {
    // slider_value(bubble)을 range의 thumb 중앙에 위치하도록 하는 수식

    // 0%와 100%에 기본적으로 thumb 값의 반을 +, - 한다
    // 그 외의 사이즈들은 해당 사이즈 값의 12%를 6으로 뺀 값으로 계산한다
    // 12%인 이유는 계산했을 때 thumb의 가장 중앙에 위치하는 값이 나와서이다
    return `calc(${activeSize}% + (${6 - Number(activeSize) * 0.12}px)`;
  };

  useEffect(() => {
    setActiveSize({
      minActiveSize: ((valueToUse("minValue") - min) * 100) / (max - min),
      maxActiveSize: ((valueToUse("maxValue") - min) * 100) / (max - min),
    });
  }, [value, min, max]);

  return (
    <DistanceSliderContainer>
      <SliderContainer>
        {DistanceValueKeyArray.map((data) => (
          <>
            <SliderStyle
              type="range"
              name={data}
              value={valueToUse(data)}
              onChange={(e) => {
                if (
                  data === "minValue" &&
                  value.maxValue <= Number(e.target.value)
                )
                  onChange("minValue", value.maxValue);
                else if (
                  data === "maxValue" &&
                  value.minValue >= Number(e.target.value)
                )
                  onChange("maxValue", value.minValue);
                else onChange(data, Number(e.target.value));

                setIsActive(data);
              }}
              min={min}
              max={max}
              style={data === isActive ? { zIndex: 10 } : {}}
            />
            {value.maxValue - value.minValue > 7 && (
              <span
                className="slider_value"
                style={{
                  left: activeStyle(
                    Number(
                      data === "minValue"
                        ? activeSize.minActiveSize
                        : activeSize.maxActiveSize
                    )
                  ),
                }}
              >
                {valueToUse(data)}
              </span>
            )}
          </>
        ))}
        <div
          className="slider_track"
          style={{
            width: activeStyle(
              Number(activeSize.maxActiveSize) -
                Number(activeSize.minActiveSize)
            ),
            left: activeStyle(Number(activeSize.minActiveSize)),
          }}
        >
          {value.maxValue - value.minValue <= 7 && (
            <span
              className="slider_value exception_slider_value"
              style={value.maxValue === value.minValue ? { left: 0 } : {}}
            >
              {value.maxValue === value.minValue
                ? value.maxValue
                : `${value.minValue} ~ ${value.maxValue}`}
            </span>
          )}
        </div>
        <div className="slider" />
      </SliderContainer>
    </DistanceSliderContainer>
  );
};

export default DistanceSlider;
