import { useEffect, useState } from "react";
import { SliderContainer, SliderStyle } from "./Slider.styled";

export type SliderProps = {
  value: number;
  onChange: (e: React.ChangeEvent<HTMLInputElement>) => void;
  min: number;
  max: number;
  // valueLabelDisplay: number;
};

const Slider = ({
  value,
  onChange,
  min,
  max,
}: // valueLabelDisplay,
SliderProps) => {
  const valueToShow = (value < min && min) || (value > max && max) || value;
  const [activeSize, setActiveSize] = useState<Number>(0);
  const activeStyle = `calc(${activeSize}% + (${
    6 - Number(activeSize) * 0.12
  }px)`;

  useEffect(() => {
    setActiveSize(((valueToShow - min) * 100) / (max - min));
  }, [valueToShow, min, max]);

  return (
    <SliderContainer>
      <span
        className="slider_value"
        style={{
          left: activeStyle,
        }}
      >
        {valueToShow}
      </span>
      <div
        className="slider_track"
        style={{
          width: activeStyle,
        }}
      />
      <SliderStyle
        type="range"
        value={valueToShow}
        onChange={(e) => onChange(e)}
        min={min}
        max={max}
      />
    </SliderContainer>
  );
};

export default Slider;
