import React, { useEffect, useState } from "react";
import ScrollTable, { ScrollColumnTypes } from "./index";
import { Meta, StoryObj } from "@storybook/react";
import {
  options as tableData,
  OptionTypes as TableTypes,
} from "../../Dropdown/DropdownOptionData";
import Checkbox from "../../Checkbox/index";
import { PaginationContainer } from "../Table/Table.styled";
import { TableColumn, TableProps } from "../Table";
import PaginationButtons from "../components/PaginationButtons";
import PageSizeDropdown from "../components/PageSizeDropdown";
import { gray } from "../../../core/colors/colors";
// import { PencilIcon, TrashIcon } from "@src/assets/Icon";
import { PencilIcon, TrashIcon } from "../../../assets/Icon/index";

const meta = {
  title: "component/Table/ScrollTable",
  component: ScrollTable,
  parameters: {
    layout: "centered",
    docs: { source: { type: "code" } },
  },
  tags: ["autodocs"],
} satisfies Meta<typeof ScrollTable>;

export default meta;
type Story = StoryObj<typeof meta>;

export const Default: Story = (args: TableProps<TableTypes>) => {
  const [page, setPage] = useState<number>(1);
  const [totalPages, setTotalPages] = useState<number>(tableData.length);
  const [size, setSize] = useState<number>(10);
  const [isChecked, setIsChecked] = useState<TableTypes[]>([]);
  const [isLoading, setIsLoading] = useState<boolean>(false);

  const handleOnChangeAllCheckbox = (
    e: React.ChangeEvent<HTMLInputElement>
  ) => {
    setIsChecked(tableData);

    if (!e.target.checked) {
      setIsChecked([]);
    }
  };

  const handleOnChangeCheckbox = (column: TableTypes) => {
    setIsChecked([...isChecked, column]);

    if (isChecked.some((data) => data.phonePlanId === column.phonePlanId)) {
      setIsChecked(isChecked.filter((v) => v !== column));
    }
  };

  const columnData: ScrollColumnTypes<TableTypes> = {
    fixed: [
      {
        label: (
          <Checkbox
            checked={isChecked.length === tableData.length}
            onChange={(e) => !isLoading && handleOnChangeAllCheckbox(e)}
          />
        ),
        renderCell: ({ row }) => (
          <Checkbox
            checked={isChecked?.some(
              (data) => data.phonePlanId === row.phonePlanId
            )}
            onChange={() => !isLoading && handleOnChangeCheckbox(row)}
          />
        ),
        className: "checkbox_div",
      },
      {
        label: "이름",
        accessKey: "name",
      },
      {
        label: "카테고리",
        accessKey: "category",
      },
    ],
    scroll: [
      {
        label: "callExp",
        accessKey: "callExp",
        className: "scroll",
      },
      {
        label: "mailExp",
        accessKey: "mailExp",
        className: "scroll",
      },
      {
        label: "dataExp",
        accessKey: "dataExp",
        className: "scroll",
      },
      {
        label: "가격",
        accessKey: "price",
        className: "scroll",
      },
    ],
    function: undefined,
  };

  return (
    <>
      <ScrollTable
        {...args}
        columns={columnData}
        tableData={tableData.slice(0, size)}
        isLoading={false}
      />
      {!isLoading && (
        <PaginationContainer>
          <PaginationButtons page={page} totalPages={totalPages} />
          <PageSizeDropdown size={size} />
        </PaginationContainer>
      )}
    </>
  );
};

Default.args = {
  columns: {
    fixed: [],
    scroll: [],
    function: [],
  },
  tableData: [],
};

export const Function: Story = (args: TableProps<TableTypes>) => {
  const [page, setPage] = useState<number>(1);
  const [totalPages, setTotalPages] = useState<number>(tableData.length);
  const [size, setSize] = useState<number>(10);
  const [isChecked, setIsChecked] = useState<TableTypes[]>([]);
  const [isLoading, setIsLoading] = useState<boolean>(false);

  const handleOnChangeAllCheckbox = (
    e: React.ChangeEvent<HTMLInputElement>
  ) => {
    setIsChecked(tableData);

    if (!e.target.checked) {
      setIsChecked([]);
    }
  };

  const handleOnChangeCheckbox = (column: TableTypes) => {
    setIsChecked([...isChecked, column]);

    if (isChecked.some((data) => data.phonePlanId === column.phonePlanId)) {
      setIsChecked(isChecked.filter((v) => v !== column));
    }
  };

  const columnData: ScrollColumnTypes<TableTypes> = {
    fixed: [
      {
        label: (
          <Checkbox
            checked={isChecked.length === tableData.length}
            onChange={(e) => !isLoading && handleOnChangeAllCheckbox(e)}
          />
        ),
        renderCell: ({ row }) => (
          <Checkbox
            checked={isChecked?.some(
              (data) => data.phonePlanId === row.phonePlanId
            )}
            onChange={() => !isLoading && handleOnChangeCheckbox(row)}
          />
        ),
        className: "checkbox_div",
      },
      {
        label: "이름",
        accessKey: "name",
      },
      {
        label: "카테고리",
        accessKey: "category",
      },
    ],
    scroll: [
      {
        label: "callExp",
        accessKey: "callExp",
        className: "scroll",
      },
      {
        label: "mailExp",
        accessKey: "mailExp",
        className: "scroll",
      },
      {
        label: "dataExp",
        accessKey: "dataExp",
        className: "scroll",
      },
      {
        label: "가격",
        accessKey: "price",
        className: "scroll",
      },
    ],
    function: [
      {
        label: "기능",
        renderCell: () => (
          <>
            <button>
              <PencilIcon size={16} stroke={gray[600]} />
            </button>
            <button>
              <TrashIcon size={16} stroke={gray[600]} />
            </button>
          </>
        ),
      },
    ],
  };

  return (
    <>
      <ScrollTable
        {...args}
        columns={columnData}
        tableData={tableData.slice(0, size)}
        isLoading={false}
      />
      {!isLoading && (
        <PaginationContainer>
          <PaginationButtons page={page} totalPages={totalPages} />
          <PageSizeDropdown size={size} />
        </PaginationContainer>
      )}
    </>
  );
};

Function.args = {
  columns: {
    fixed: [],
    scroll: [],
    function: [],
  },
  tableData: [],
};

export const Loading: Story = (args: TableProps<TableTypes>) => {
  const columnData: ScrollColumnTypes<TableTypes> = {
    fixed: [
      {
        label: <Checkbox checked={false} onChange={() => {}} />,
        renderCell: () => <Checkbox checked={false} onChange={() => {}} />,
        className: "checkbox_div",
      },
      {
        label: "이름",
        accessKey: "name",
      },
      {
        label: "카테고리",
        accessKey: "category",
      },
    ],
    scroll: [
      {
        label: "callExp",
        accessKey: "callExp",
        className: "scroll",
      },
      {
        label: "mailExp",
        accessKey: "mailExp",
        className: "scroll",
      },
      {
        label: "dataExp",
        accessKey: "dataExp",
        className: "scroll",
      },
      {
        label: "가격",
        accessKey: "price",
        className: "scroll",
      },
    ],
    function: undefined,
  };

  return <ScrollTable {...args} columns={columnData} />;
};

Loading.args = {
  columns: {
    fixed: [],
    scroll: [],
    function: [],
  },
  tableData: tableData.slice(0, 10),
  isLoading: true,
};
